
def hello(world):
    return 'Hello, ' + world

